@@ -35,7 +35,7 @@ def runMain(moduleName=None, **parDict):
         isDebug = not not moduleName
         try:
             logFolder = b.getPath(workspacePath, "log")
-            for logFile in sorted(b.getAllFileList(logFolder))[100:]:
+            for logFile in sorted(b.getAllFileList(logFolder), reverse=True)[100:]:
                 b.remove(logFile)
             logFile = b.getPath(logFolder, f"{time.strftime('%Y%m%d_%H%M%S')}.log")
             b.initLogger(logFile=logFile)
